@@ -5,6 +5,17 @@
 import cython
 
 
+import sys
+IS_PY2 = sys.version_info < (3, 0)
+
+
+def print_big_ints(t):
+    s = repr(t)
+    if IS_PY2:
+        s = s.replace('L', '')
+    print(s)
+
+
 @cython.test_fail_if_path_exists(
     "//UnaryMinusNode",
     "//UnaryPlusNode",
@@ -109,6 +120,33 @@ def binop_bool():
     return plus1, pmix1, minus1, and1, or1, ormix1, xor1, plus3, pmix3, minus3, and3, or3, ormix3, xor3
 
 
+@cython.test_fail_if_path_exists(
+    "//MulNode",
+    "//PowNode",
+)
+def binop_mul_pow():
+    """
+    >>> print_big_ints(binop_mul_pow())
+    (800, 12193263111263526900, 248832, 12467572902176589255564000298710470656)
+    """
+    mul_int = 20 * 40
+    mul_large_int = 1234567890 * 9876543210
+    pow_int = 12 ** 5
+    pow_large_int = 1234 ** 12
+    return (mul_int, mul_large_int, pow_int, pow_large_int)
+
+
+def binop_pow_negative():
+    """
+    >>> print_big_ints(binop_pow_negative())
+    (4.018775720164609e-06, 8.020807320287816e-38, 0.1)
+    """
+    pow_int = 12 ** -5
+    pow_large_int = 1234 ** -12
+    pow_expression_int = 10 ** (1-2)
+    return (pow_int, pow_large_int, pow_expression_int)
+
+
 @cython.test_fail_if_path_exists(
     "//SliceIndexNode",
 )
@@ -291,6 +329,28 @@ def mult_empty_list():
     return 5 * [] * 100
 
 
+@cython.test_fail_if_path_exists(
+    "//MulNode",
+)
+def mult_list_int_int():
+    """
+    >>> mult_list_int_int()
+    [1, 2, 1, 2, 1, 2, 1, 2, 1, 2, 1, 2]
+    """
+    return [1, 2] * 2 * 3
+
+
+@cython.test_fail_if_path_exists(
+    "//MulNode",
+)
+def mult_int_list_int():
+    """
+    >>> mult_int_list_int()
+    [1, 2, 1, 2, 1, 2, 1, 2, 1, 2, 1, 2]
+    """
+    return 3 * [1, 2] * 2
+
+
 @cython.test_fail_if_path_exists(
     "//MulNode",
     "//ListNode//IntNode",
@@ -364,20 +424,20 @@ def combined():
 
 
 @cython.test_assert_path_exists(
-    '//IntNode[@value = "2"]',
-    '//IntNode[@value = "4"]',
-    '//IntNode[@value = "5"]',
-    '//IntNode[@value = "7"]',
+    '//IntNode[@base_10_value = "2"]',
+    '//IntNode[@base_10_value = "4"]',
+    '//IntNode[@base_10_value = "5"]',
+    '//IntNode[@base_10_value = "7"]',
     '//BoolBinopNode//PrimaryCmpNode',
-    '//BoolBinopNode[.//PrimaryCmpNode//IntNode[@value = "4"] and .//PrimaryCmpNode//IntNode[@value = "5"]]',
-    '//PrimaryCmpNode[.//IntNode[@value = "2"] and .//IntNode[@value = "4"]]',
-    '//PrimaryCmpNode[.//IntNode[@value = "5"] and .//IntNode[@value = "7"]]',
+    '//BoolBinopNode[.//PrimaryCmpNode//IntNode[@base_10_value = "4"] and .//PrimaryCmpNode//IntNode[@base_10_value = "5"]]',
+    '//PrimaryCmpNode[.//IntNode[@base_10_value = "2"] and .//IntNode[@base_10_value = "4"]]',
+    '//PrimaryCmpNode[.//IntNode[@base_10_value = "5"] and .//IntNode[@base_10_value = "7"]]',
 )
 @cython.test_fail_if_path_exists(
-    '//IntNode[@value = "1"]',
-    '//IntNode[@value = "8"]',
-    '//PrimaryCmpNode[.//IntNode[@value = "4"] and .//IntNode[@value = "5"]]',
-    '//PrimaryCmpNode[.//IntNode[@value = "2"] and .//IntNode[@value = "7"]]',
+    '//IntNode[@base_10_value = "1"]',
+    '//IntNode[@base_10_value = "8"]',
+    '//PrimaryCmpNode[.//IntNode[@base_10_value = "4"] and .//IntNode[@base_10_value = "5"]]',
+    '//PrimaryCmpNode[.//IntNode[@base_10_value = "2"] and .//IntNode[@base_10_value = "7"]]',
     '//BoolNode',
 )
 def cascaded_cmp_with_partial_constants(a, b):
@@ -397,22 +457,22 @@ def cascaded_cmp_with_partial_constants(a, b):
 
 
 @cython.test_assert_path_exists(
-    '//IntNode[@value = "2"]',
-    '//IntNode[@value = "4"]',
-    '//IntNode[@value = "5"]',
-    '//IntNode[@value = "7"]',
+    '//IntNode[@base_10_value = "2"]',
+    '//IntNode[@base_10_value = "4"]',
+    '//IntNode[@base_10_value = "5"]',
+    '//IntNode[@base_10_value = "7"]',
     '//BoolBinopNode',
     '//SingleAssignmentNode//BoolBinopNode',
     '//SingleAssignmentNode//BoolBinopNode//NameNode[@name = "a"]',
     '//SingleAssignmentNode//BoolBinopNode//NameNode[@name = "b"]',
-    '//BoolBinopNode[.//PrimaryCmpNode//IntNode[@value = "4"] and .//PrimaryCmpNode//IntNode[@value = "5"]]',
+    '//BoolBinopNode[.//PrimaryCmpNode//IntNode[@base_10_value = "4"] and .//PrimaryCmpNode//IntNode[@base_10_value = "5"]]',
     '//BoolNode[@value = False]',
 )
 @cython.test_fail_if_path_exists(
     '//SingleAssignmentNode//NameNode[@name = "c"]',
-    '//IntNode[@value = "1"]',
-    '//PrimaryCmpNode[.//IntNode[@value = "4"] and .//IntNode[@value = "5"]]',
-    '//PrimaryCmpNode[.//IntNode[@value = "2"] and .//IntNode[@value = "7"]]',
+    '//IntNode[@base_10_value = "1"]',
+    '//PrimaryCmpNode[.//IntNode[@base_10_value = "4"] and .//IntNode[@base_10_value = "5"]]',
+    '//PrimaryCmpNode[.//IntNode[@base_10_value = "2"] and .//IntNode[@base_10_value = "7"]]',
     '//BoolNode[@value = True]',
 )
 def cascaded_cmp_with_partial_constants_and_false_end(a, b, c):
@@ -433,13 +493,13 @@ def cascaded_cmp_with_partial_constants_and_false_end(a, b, c):
 @cython.test_assert_path_exists(
     '//PrimaryCmpNode',
     '//PrimaryCmpNode//IntNode',
-    '//PrimaryCmpNode//IntNode[@value = "0"]',
-    '//PrimaryCmpNode//IntNode[@value = "4294967296"]',
+    '//PrimaryCmpNode//IntNode[@base_10_value = "0"]',
+    '//PrimaryCmpNode//IntNode[@base_10_value = "4294967296"]',
 )
 @cython.test_fail_if_path_exists(
     '//PrimaryCmpNode//IntBinopNode',
-    '//PrimaryCmpNode//IntNode[@value = "1"]',
-    '//PrimaryCmpNode//IntNode[@value = "32"]',
+    '//PrimaryCmpNode//IntNode[@base_10_value = "1"]',
+    '//PrimaryCmpNode//IntNode[@base_10_value = "32"]',
 )
 def const_in_binop(v):
     """
